SimulatedWeatherProvider class

Implemented types

Constructors

SimulatedWeatherProvider({Duration interval = const Duration(seconds: 5)})
Creates a simulated weather provider.

Properties

conditions Stream<WeatherCondition>
Stream of weather condition updates.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
interval Duration
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
Release all resources.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
startMonitoring() Future<void>
Start monitoring weather conditions.
override
stopMonitoring() Future<void>
Stop monitoring weather conditions.
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited